==> duiba-activity-service-api-0.0.1-20220330.014630-37-sources.jar: cn/com/duiba/cloud/duiba/activity/service/api/remoteservice/playways/scoring/ScoringUserRequestApi.java <==
package cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.scoring;

import cn.com.duiba.cloud.duiba.activity.service.api.dto.PlaywayActionRecordDTO;
import cn.com.duiba.cloud.duiba.activity.service.api.exception.ApiException;
import cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.Ranking;

import java.util.List;

/**
 * 记分玩法API
 * 1.用户请求记分玩法的接口时，自定义代码区域可使用此API
 *
 */
public interface ScoringUserRequestApi {


    /**
     * 提交分数
     * @param startId 参与记录
     * @param score 提交的分数
     */
    void submitScore(Long activityId, String playwayId, Long cid, long startId, int score);

    /**
     * 提交分数
     * @param startId 参与记录
     * @param score 提交的分数
     */
    void submitScore(Long activityId, String playwayId, Long cid, long startId, int score, String rankPlaywayId);

    /**
     * 查询我的今日参与次数
     * 游戏参与次数，只计算action=start
     * @return 用户当前活动今日的参与次数
     */
    Long queryMyTodayCount(Long activityId, String playwayId, Long cid);

    /**
     * 通过id查询参与记录
     * @param startId 参与id
     * @return ActionRecordDto
     */
    PlaywayActionRecordDTO findById(Long activityId, long startId);

    /**
     * 查询一次游戏提交的次数
     * @param startId 参与id
     * @return 次数
     */
    int countTimes(long startId);

    /**
     * 获取前几名的排行榜信息
     * @param topN 前几名
     *             不允许调用超过3000名的排名，会有性能问题
     * @return ranking 列表
     */
    List<Ranking> getTopN(Long activityId, int topN);

    /**
     * 获取前几名的排行榜信息
     * @param rankPlaywayId 排行榜玩法ID
     * @param topN 前几名
     *             不允许调用超过3000名的排名，会有性能问题
     * @return ranking 列表
     */
    List<Ranking> getTopN(Long activityId, String rankPlaywayId, int topN);


//    /**
//     * 获取上期排行榜当前用户信息
//     * 排行榜已结束-返回最后一期
//     * 排行榜未结束-返回上一期
//     * @return
//     */
//    RankingUserPrizeRecord getPreMyRank();
//
//    /**
//     * 获取上期排行榜当前用户信息
//     * 排行榜已结束-返回最后一期
//     * 排行榜未结束-返回上一期
//     * @param rankPlaywayId 排行榜玩法ID
//     * @return
//     */
//    RankingUserPrizeRecord getPreMyRank(String rankPlaywayId);
//
//    /**
//     * 获取上期排行榜当前用户信息
//     * 排行榜已结束-返回最后一期
//     * 排行榜未结束-返回上一期
//     * @param rankPlaywayId 排行榜玩法ID
//     * @return
//     */
//    RankingUserPrizeRecord getPreMyRank(String rankPlaywayId, String userId);


    /**
     * 获取新排行榜当前正在进行中的rankingType
     * 如果排行榜已结束，返回的是最后一期
     * 如果排行榜未开始，返回的是第一期
     * @return
     * @throws ApiException
     */
    String getCurrentRankingType(Long activityId) throws ApiException;


    /**
     * 获取新排行榜当前正在进行中的rankingType
     * 如果排行榜已结束，返回的是最后一期
     * 如果排行榜未开始，返回的是第一期
     * @param rankPlaywayId 排行榜玩法ID
     * @return
     * @throws ApiException
     */
    String getCurrentRankingType(Long activityId, String rankPlaywayId) throws ApiException;

    /**
     * 获取新排行榜上一期的rankingType
     *
     * @return
     * @throws ApiException
     */
    String getPrefixRankingType(Long activityId) throws ApiException;

    /**
     * 获取新排行榜上一期的rankingType
     * @param rankPlaywayId 排行榜玩法ID
     *
     * @return
     * @throws ApiException
     */
    String getPrefixRankingType(Long activityId, String rankPlaywayId) throws ApiException;

}

==> duiba-activity-service-api-0.0.1-20220401.100053-74-sources.jar: cn/com/duiba/cloud/duiba/activity/service/api/remoteservice/playways/scoring/ScoringUserRequestApi.java <==
package cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.scoring;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.dto.PlaywayActionRecordDTO;
import cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.Ranking;

import java.util.List;

/**
 * 记分玩法API
 * 1.用户请求记分玩法的接口时，自定义代码区域可使用此API
 *
 */
public interface ScoringUserRequestApi {


    /**
     * 提交分数
     * @param startId 参与记录
     * @param score 提交的分数
     */
    void submitScore(Long activityId, String playwayId, Long cid, long startId, int score) throws BizException;

    /**
     * 提交分数
     * @param startId 参与记录
     * @param score 提交的分数
     */
    void submitScore(Long activityId, String playwayId, Long cid, long startId, int score, String rankPlaywayId) throws BizException;

    /**
     * 查询我的今日参与次数
     * 游戏参与次数，只计算action=start
     * @return 用户当前活动今日的参与次数
     */
    Long queryMyTodayCount(Long activityId, String playwayId, Long cid);

    /**
     * 通过id查询参与记录
     * @param startId 参与id
     * @return ActionRecordDto
     */
    PlaywayActionRecordDTO findById(Long activityId, long startId);

    /**
     * 查询一次游戏提交的次数
     * @param startId 参与id
     * @return 次数
     */
    int countTimes(long startId);

    /**
     * 获取前几名的排行榜信息
     * @param topN 前几名
     *             不允许调用超过3000名的排名，会有性能问题
     * @return ranking 列表
     */
    List<Ranking> getTopN(Long activityId, int topN);

    /**
     * 获取前几名的排行榜信息
     * @param rankPlaywayId 排行榜玩法ID
     * @param topN 前几名
     *             不允许调用超过3000名的排名，会有性能问题
     * @return ranking 列表
     */
    List<Ranking> getTopN(Long activityId, String rankPlaywayId, int topN);


//    /**
//     * 获取上期排行榜当前用户信息
//     * 排行榜已结束-返回最后一期
//     * 排行榜未结束-返回上一期
//     * @return
//     */
//    RankingUserPrizeRecord getPreMyRank();
//
//    /**
//     * 获取上期排行榜当前用户信息
//     * 排行榜已结束-返回最后一期
//     * 排行榜未结束-返回上一期
//     * @param rankPlaywayId 排行榜玩法ID
//     * @return
//     */
//    RankingUserPrizeRecord getPreMyRank(String rankPlaywayId);
//
//    /**
//     * 获取上期排行榜当前用户信息
//     * 排行榜已结束-返回最后一期
//     * 排行榜未结束-返回上一期
//     * @param rankPlaywayId 排行榜玩法ID
//     * @return
//     */
//    RankingUserPrizeRecord getPreMyRank(String rankPlaywayId, String userId);


    /**
     * 获取新排行榜当前正在进行中的rankingType
     * 如果排行榜已结束，返回的是最后一期
     * 如果排行榜未开始，返回的是第一期
     * @return
     * @throws BizException
     */
    String getCurrentRankingType(Long activityId) throws BizException;


    /**
     * 获取新排行榜当前正在进行中的rankingType
     * 如果排行榜已结束，返回的是最后一期
     * 如果排行榜未开始，返回的是第一期
     * @param rankPlaywayId 排行榜玩法ID
     * @return
     * @throws BizException
     */
    String getCurrentRankingType(Long activityId, String rankPlaywayId) throws BizException;

    /**
     * 获取新排行榜上一期的rankingType
     *
     * @return
     * @throws BizException
     */
    String getPrefixRankingType(Long activityId) throws BizException;

    /**
     * 获取新排行榜上一期的rankingType
     * @param rankPlaywayId 排行榜玩法ID
     *
     * @return
     * @throws BizException
     */
    String getPrefixRankingType(Long activityId, String rankPlaywayId) throws BizException;

}
